<div align="center">
  <img 
    src="https://github.com/lavecat/Kxspy/blob/main/assets/kxspy_banner.png" 
    alt="kxspy Banner" 
    style="border-radius: 5px;">
  <h1>Kxspy</h1>
  <h3>Kxspy is a async python client for KxsClient Network</h3>
  <div>&nbsp;</div>
</div>

> [!WARNING]
> Kxspy is in beta version, so some features may not work as expected.
> Please report any issues you encounter on the GitHub repository.


## Features
- [x] **Auto-Reconnect**
- [x] **Full websocket & RestAPI**
- [x] **Easy to use**
- [x] **Example**
- [x] ***And more...***

## Getting Started
```shell
pip install kxspy
```
**You can now choose an example or do it yourself, and you can consult the documentation to help you.**


## Need help ?
- Discord server : https://discord.wf/kxsclient ( mention @lirus_12345 for help )
- Documentation : https://kxspy.readthedocs.io/



